"""Change experiment schedule data type

Revision ID: 9f766facc4ab
Revises: 09746a50372f
Create Date: 2021-01-08 11:03:43.274138

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9f766facc4ab"
down_revision = "09746a50372f"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("experiments", "start_date", type_=sa.Date)
    op.alter_column("experiments", "end_date", type_=sa.Date)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column("experiments", "start_date", type_=sa.DateTime)
    op.alter_column("experiments", "end_date", type_=sa.DateTime)
    # ### end Alembic commands ###
