# Import all the models, so that Base has them before being
# imported by Alembic
from abing.db.base_class import Base  # noqa
from abing.models.user import User  # noqa
from abing.models.experiment import Experiment  # noqa
from abing.models.arm import Arm  # noqa
from abing.models.feature import Feature  # noqa
from abing.models.allocation import Allocation  # noqa
