"""Add traffic weight Column to Arm model

Revision ID: 582710b9fab6
Revises: 88b3cab99dfd
Create Date: 2020-12-20 05:29:49.834686

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "582710b9fab6"
down_revision = "88b3cab99dfd"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("arms", sa.Column("traffic_weight", sa.Integer(), nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("arms", "traffic_weight")
    # ### end Alembic commands ###
