.abing-header{position:relative;z-index:10;max-width:100%;box-shadow:0 2px 8px #f0f1f2;background:#fff;height:64px}.abing-header .logo{height:48px;margin:8px 16px}.abing-menu{height:100%}.abing-menu.ant-menu-horizontal{border-bottom:1px solid transparent}.abing-menu>.menu-item{height:64px;margin-right:12px;margin-left:12px;line-height:60px;border-top:2px solid transparent;border-bottom:2px solid transparent}.mobile-menu-icon{position:absolute;top:23px;right:30px;z-index:1;width:16px;height:22px}.abing-mobile-menu{width:100%}@media only screen and (max-width:767.5px){.abing-header{text-align:center}.abing-menu{display:none}}@media only screen and (min-width:767.5px){.mobile-menu-icon{display:none}}@media screen and (min-width:769px){.login-form{max-width:460px}}.login-form-button{width:100%}.login-form-container{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.login-logo{min-width:300px}@media screen and (min-width:480px){.login-logo{min-width:460px}}tr.ant-table-expanded-row .abing-experiment-descriptions .ant-descriptions-view table{width:100%}body{margin:0;font-family:-apple-system,BlinkMacSystemFont,"Segoe UI","Roboto","Oxygen","Ubuntu","Cantarell","Fira Sans","Droid Sans","Helvetica Neue",sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}code{font-family:source-code-pro,Menlo,Monaco,Consolas,"Courier New",monospace}
/*# sourceMappingURL=main.7fa45826.chunk.css.map */